@@ -29,6 +29,7 @@ testinfra_hosts = testinfra.utils.ansible_runner.AnsibleRunner(
     'path',
     ['ceph',
      'cinder',
+     'cloudkitty',
      'designate',
      'fluentd/filter',
      'fluentd/input',
@@ -48,6 +49,7 @@ testinfra_hosts = testinfra.utils.ansible_runner.AnsibleRunner(
      'neutron',
      'nova',
      'octavia',
+     'prometheus',
      'sahara',
      'storm',
      'swift',
@@ -61,6 +63,7 @@ def test_service_config_directory(host, path):
     'path',
     ['ceph.conf',
      'cinder.conf',
+     'cloudkitty.conf',
      'designate.conf',
      'galera.cnf',
      'glance.conf',
@@ -78,6 +81,7 @@ def test_service_config_directory(host, path):
      'nova.conf',
      'octavia.conf',
      'sahara.conf',
+     'backup.my.cnf',
      'zookeeper.cfg'])
 def test_service_ini_file(host, path):
     # TODO(mgoddard): Check more of config file contents.
@@ -90,8 +94,7 @@ def test_service_ini_file(host, path):
 @pytest.mark.parametrize(
     'path',
     ['ironic/ironic-agent.initramfs',
-     'ironic/ironic-agent.kernel',
-     'ironic/pxelinux.default'])
+     'ironic/ironic-agent.kernel'])
 def test_service_non_ini_file(host, path):
     # TODO(mgoddard): Check config file contents.
     path = os.path.join('/etc/kolla/config', path)
